# Messmer human ESC (Smart-seq2) {#messmer-hesc}

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Introduction

This performs an analysis of the human embryonic stem cell (hESC) dataset generated with Smart-seq2 [@messmer2019transcriptional], which contains several plates of naive and primed hESCs.
The chapter's code is based on the steps in the paper's [GitHub repository](https://github.com/MarioniLab/NaiveHESC2016/blob/master/analysis/preprocess.Rmd), with some additional steps for cell cycle effect removal contributed by Philippe Boileau.

## Data loading

Converting the batch to a factor, to make life easier later on.


```r
library(scRNAseq)
sce.mess <- MessmerESCData()
sce.mess$`experiment batch` <- factor(sce.mess$`experiment batch`)
```


```r
library(AnnotationHub)
ens.hs.v97 <- AnnotationHub()[["AH73881"]]
anno <- select(ens.hs.v97, keys=rownames(sce.mess), 
    keytype="GENEID", columns=c("SYMBOL"))
rowData(sce.mess) <- anno[match(rownames(sce.mess), anno$GENEID),]
```

## Quality control



Let's have a look at the QC statistics.


```r
colSums(as.matrix(filtered))
```

```
##              low_lib_size            low_n_features high_subsets_Mito_percent 
##                       107                        99                        22 
## high_altexps_ERCC_percent                   discard 
##                       117                       156
```


```r
gridExtra::grid.arrange(
    plotColData(original, x="experiment batch", y="sum",
        colour_by=I(filtered$discard), other_field="phenotype") +
        facet_wrap(~phenotype) + scale_y_log10(),
    plotColData(original, x="experiment batch", y="detected",
        colour_by=I(filtered$discard), other_field="phenotype") +
        facet_wrap(~phenotype) + scale_y_log10(),
    plotColData(original, x="experiment batch", y="subsets_Mito_percent",
        colour_by=I(filtered$discard), other_field="phenotype") +
        facet_wrap(~phenotype),
    plotColData(original, x="experiment batch", y="altexps_ERCC_percent",
        colour_by=I(filtered$discard), other_field="phenotype") +
        facet_wrap(~phenotype),
    ncol=1
)
```

<div class="figure">
<img src="messmer-hesc_files/figure-html/unref-messmer-hesc-qc-1.png" alt="Distribution of QC metrics across batches (x-axis) and phenotypes (facets) for cells in the Messmer hESC dataset. Each point is a cell and is colored by whether it was discarded." width="576" />
<p class="caption">(\#fig:unref-messmer-hesc-qc)Distribution of QC metrics across batches (x-axis) and phenotypes (facets) for cells in the Messmer hESC dataset. Each point is a cell and is colored by whether it was discarded.</p>
</div>

## Normalization


```r
library(scran)

set.seed(10000)
clusters <- quickCluster(sce.mess)
sce.mess <- computeSumFactors(sce.mess, cluster=clusters)
sce.mess <- logNormCounts(sce.mess)
```


```r
par(mfrow=c(1,2))
plot(sce.mess$sum, sizeFactors(sce.mess), log = "xy", pch=16,
     xlab = "Library size (millions)", ylab = "Size factor",
     col = ifelse(sce.mess$phenotype == "naive", "black", "grey"))

spike.sf <- librarySizeFactors(altExp(sce.mess, "ERCC"))
plot(sizeFactors(sce.mess), spike.sf, log = "xy", pch=16,
     ylab = "Spike-in size factor", xlab = "Deconvolution size factor",
     col = ifelse(sce.mess$phenotype == "naive", "black", "grey"))
```

<div class="figure">
<img src="messmer-hesc_files/figure-html/unref-messmer-hesc-norm-1.png" alt="Deconvolution size factors plotted against the library size (left) and spike-in size factors plotted against the deconvolution size factors (right). Each point is a cell and is colored by its phenotype." width="672" />
<p class="caption">(\#fig:unref-messmer-hesc-norm)Deconvolution size factors plotted against the library size (left) and spike-in size factors plotted against the deconvolution size factors (right). Each point is a cell and is colored by its phenotype.</p>
</div>

## Cell cycle phase assignment

Here, we use multiple cores to speed up the processing.


```r
set.seed(10001)
hs_pairs <- readRDS(system.file("exdata", "human_cycle_markers.rds", package="scran"))
assigned <- cyclone(sce.mess, pairs=hs_pairs, 
    gene.names=rownames(sce.mess),
    BPPARAM=BiocParallel::MulticoreParam(10))
sce.mess$phase <- assigned$phases
```


```r
table(sce.mess$phase)
```

```
## 
##  G1 G2M   S 
## 460 406 322
```


```r
smoothScatter(assigned$scores$G1, assigned$scores$G2M, xlab="G1 score",
     ylab="G2/M score", pch=16)
```

<div class="figure">
<img src="messmer-hesc_files/figure-html/unref-messmer-hesc-cyclone-1.png" alt="G1 `cyclone()` phase scores against the G2/M phase scores for each cell in the Messmer hESC dataset." width="672" />
<p class="caption">(\#fig:unref-messmer-hesc-cyclone)G1 `cyclone()` phase scores against the G2/M phase scores for each cell in the Messmer hESC dataset.</p>
</div>

## Feature selection


```r
dec <- modelGeneVarWithSpikes(sce.mess, "ERCC", block = sce.mess$`experiment batch`)
top.hvgs <- getTopHVGs(dec, prop = 0.1)
```


```r
par(mfrow=c(1,3))
for (i in seq_along(dec$per.block)) {
    current <- dec$per.block[[i]]
    plot(current$mean, current$total, xlab="Mean log-expression", 
        ylab="Variance", pch=16, cex=0.5, main=paste("Batch", i))

    fit <- metadata(current)
    points(fit$mean, fit$var, col="red", pch=16)
    curve(fit$trend(x), col='dodgerblue', add=TRUE, lwd=2)
}
```

<div class="figure">
<img src="messmer-hesc_files/figure-html/unref-messmer-hesc-var-1.png" alt="Per-gene variance of the log-normalized expression values in the Messmer hESC dataset, plotted against the mean for each batch. Each point represents a gene with spike-ins shown in red and the fitted trend shown in blue." width="1152" />
<p class="caption">(\#fig:unref-messmer-hesc-var)Per-gene variance of the log-normalized expression values in the Messmer hESC dataset, plotted against the mean for each batch. Each point represents a gene with spike-ins shown in red and the fitted trend shown in blue.</p>
</div>

## Batch correction 

We eliminate the obvious batch effect between batches with linear regression, which is possible due to the replicated nature of the experimental design.
We set `keep=1:2` to retain the effect of the first two coefficients in `design` corresponding to our phenotype of interest.


```r
library(batchelor)
sce.mess <- correctExperiments(sce.mess, 
    PARAM = RegressParam(
        design = model.matrix(~sce.mess$phenotype + sce.mess$`experiment batch`),
        keep = 1:2 
    )
)
```

## Dimensionality Reduction

We could have set `d=` and `subset.row=` in `correctExperiments()` to automatically perform a PCA on the the residual matrix with the subset of HVGs,
but we'll just explicitly call `runPCA()` here to keep things simple.


```r
set.seed(1101001)
sce.mess <- runPCA(sce.mess, subset_row = top.hvgs, exprs_values = "corrected")
sce.mess <- runTSNE(sce.mess, dimred = "PCA", perplexity = 40)
```

From a naive PCA, the cell cycle appears to be a major source of biological variation within each phenotype.


```r
gridExtra::grid.arrange(
    plotTSNE(sce.mess, colour_by = "phenotype") + ggtitle("By phenotype"),
    plotTSNE(sce.mess, colour_by = "experiment batch") + ggtitle("By batch "),
    plotTSNE(sce.mess, colour_by = "CDK1", swap_rownames="SYMBOL") + ggtitle("By CDK1"),
    plotTSNE(sce.mess, colour_by = "phase") + ggtitle("By phase"),
    ncol = 2
)
```

<div class="figure">
<img src="messmer-hesc_files/figure-html/unref-messmer-hesc-tsne-1.png" alt="Obligatory $t$-SNE plots of the Messmer hESC dataset, where each point is a cell and is colored by various attributes." width="960" />
<p class="caption">(\#fig:unref-messmer-hesc-tsne)Obligatory $t$-SNE plots of the Messmer hESC dataset, where each point is a cell and is colored by various attributes.</p>
</div>

We perform contrastive PCA (cPCA) and sparse cPCA (scPCA) on the corrected log-expression data to obtain the same number of PCs.
Given that the naive hESCs are actually reprogrammed primed hESCs, we will use the single batch of primed-only hESCs as the "background" dataset to remove the cell cycle effect.


```r
library(scPCA)
is.bg <- sce.mess$`experiment batch`=="3"
target <- sce.mess[,!is.bg]
background <- sce.mess[,is.bg]

mat.target <- t(assay(target, "corrected")[top.hvgs,])
mat.background <- t(assay(background, "corrected")[top.hvgs,])

set.seed(1010101001)
con_out <- scPCA(
    target = mat.target,
    background = mat.background,
    penalties = 0, # no penalties = non-sparse cPCA.
    n_eigen = 50,
    contrasts = 100
)
reducedDim(target, "cPCA") <- con_out$x
```


```r
set.seed(101010101)
sparse_con_out <- scPCA(
    target = mat.target,
    background = mat.background,
    penalties = 1e-4,
    n_eigen = 50,
    contrasts = 100,
    alg = "rand_var_proj" # for speed.
)
reducedDim(target, "scPCA") <- sparse_con_out$x
```

We see greater intermingling between phases within both the naive and primed cells after cPCA and scPCA.


```r
set.seed(1101001)
target <- runTSNE(target, dimred = "cPCA", perplexity = 40, name="cPCA+TSNE")
target <- runTSNE(target, dimred = "scPCA", perplexity = 40, name="scPCA+TSNE")
```


```r
gridExtra::grid.arrange(
    plotReducedDim(target, "cPCA+TSNE", colour_by = "phase") + ggtitle("After cPCA"),
    plotReducedDim(target, "scPCA+TSNE", colour_by = "phase") + ggtitle("After scPCA"),
    ncol=2
)
```

<div class="figure">
<img src="messmer-hesc_files/figure-html/unref-messmer-hesc-cpca-tsne-1.png" alt="More $t$-SNE plots of the Messmer hESC dataset after cPCA and scPCA, where each point is a cell and is colored by its assigned cell cycle phase." width="960" />
<p class="caption">(\#fig:unref-messmer-hesc-cpca-tsne)More $t$-SNE plots of the Messmer hESC dataset after cPCA and scPCA, where each point is a cell and is colored by its assigned cell cycle phase.</p>
</div>

We can quantify the change in the separation between phases within each phenotype using the silhouette coefficient.


```r
library(bluster)
naive <- target[,target$phenotype=="naive"]
primed <- target[,target$phenotype=="primed"]

N <- approxSilhouette(reducedDim(naive, "PCA"), naive$phase)
P <- approxSilhouette(reducedDim(primed, "PCA"), primed$phase)
c(naive=mean(N$width), primed=mean(P$width))
```

```
##   naive  primed 
## 0.02032 0.03025
```

```r
cN <- approxSilhouette(reducedDim(naive, "cPCA"), naive$phase)
cP <- approxSilhouette(reducedDim(primed, "cPCA"), primed$phase)
c(naive=mean(cN$width), primed=mean(cP$width))
```

```
##    naive   primed 
## 0.007696 0.011941
```

```r
scN <- approxSilhouette(reducedDim(naive, "scPCA"), naive$phase)
scP <- approxSilhouette(reducedDim(primed, "scPCA"), primed$phase)
c(naive=mean(scN$width), primed=mean(scP$width))
```

```
##    naive   primed 
## 0.006614 0.014601
```



## Session Info {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R version 4.1.0 (2021-05-18)
Platform: x86_64-pc-linux-gnu (64-bit)
Running under: Ubuntu 20.04.2 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.13-bioc/R/lib/libRblas.so
LAPACK: /home/biocbuild/bbs-3.13-bioc/R/lib/libRlapack.so

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_US.UTF-8        LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

attached base packages:
[1] parallel  stats4    stats     graphics  grDevices utils     datasets 
[8] methods   base     

other attached packages:
 [1] bluster_1.2.0               scPCA_1.6.0                
 [3] batchelor_1.8.0             scran_1.20.0               
 [5] scater_1.20.0               ggplot2_3.3.3              
 [7] scuttle_1.2.0               AnnotationHub_3.0.0        
 [9] BiocFileCache_2.0.0         dbplyr_2.1.1               
[11] ensembldb_2.16.0            AnnotationFilter_1.16.0    
[13] GenomicFeatures_1.44.0      AnnotationDbi_1.54.0       
[15] scRNAseq_2.6.0              SingleCellExperiment_1.14.0
[17] SummarizedExperiment_1.22.0 Biobase_2.52.0             
[19] GenomicRanges_1.44.0        GenomeInfoDb_1.28.0        
[21] IRanges_2.26.0              S4Vectors_0.30.0           
[23] BiocGenerics_0.38.0         MatrixGenerics_1.4.0       
[25] matrixStats_0.58.0          BiocStyle_2.20.0           
[27] rebook_1.2.0               

loaded via a namespace (and not attached):
  [1] igraph_1.2.6                  lazyeval_0.2.2               
  [3] listenv_0.8.0                 BiocParallel_1.26.0          
  [5] digest_0.6.27                 htmltools_0.5.1.1            
  [7] viridis_0.6.1                 fansi_0.4.2                  
  [9] magrittr_2.0.1                memoise_2.0.0                
 [11] ScaledMatrix_1.0.0            cluster_2.1.2                
 [13] limma_3.48.0                  globals_0.14.0               
 [15] Biostrings_2.60.0             prettyunits_1.1.1            
 [17] colorspace_2.0-1              blob_1.2.1                   
 [19] rappdirs_0.3.3                rbibutils_2.1.1              
 [21] xfun_0.23                     dplyr_1.0.6                  
 [23] crayon_1.4.1                  RCurl_1.98-1.3               
 [25] jsonlite_1.7.2                graph_1.70.0                 
 [27] glue_1.4.2                    gtable_0.3.0                 
 [29] zlibbioc_1.38.0               XVector_0.32.0               
 [31] DelayedArray_0.18.0           coop_0.6-2                   
 [33] kernlab_0.9-29                BiocSingular_1.8.0           
 [35] future.apply_1.7.0            abind_1.4-5                  
 [37] scales_1.1.1                  edgeR_3.34.0                 
 [39] DBI_1.1.1                     Rcpp_1.0.6                   
 [41] viridisLite_0.4.0             xtable_1.8-4                 
 [43] progress_1.2.2                dqrng_0.3.0                  
 [45] bit_4.0.4                     rsvd_1.0.5                   
 [47] ResidualMatrix_1.2.0          metapod_1.0.0                
 [49] httr_1.4.2                    dir.expiry_1.0.0             
 [51] ellipsis_0.3.2                pkgconfig_2.0.3              
 [53] XML_3.99-0.6                  farver_2.1.0                 
 [55] CodeDepends_0.6.5             sass_0.4.0                   
 [57] locfit_1.5-9.4                utf8_1.2.1                   
 [59] tidyselect_1.1.1              labeling_0.4.2               
 [61] rlang_0.4.11                  later_1.2.0                  
 [63] munsell_0.5.0                 BiocVersion_3.13.1           
 [65] tools_4.1.0                   cachem_1.0.5                 
 [67] generics_0.1.0                RSQLite_2.2.7                
 [69] ExperimentHub_2.0.0           evaluate_0.14                
 [71] stringr_1.4.0                 fastmap_1.1.0                
 [73] yaml_2.2.1                    knitr_1.33                   
 [75] bit64_4.0.5                   purrr_0.3.4                  
 [77] KEGGREST_1.32.0               future_1.21.0                
 [79] sparseMatrixStats_1.4.0       mime_0.10                    
 [81] origami_1.0.3                 biomaRt_2.48.0               
 [83] compiler_4.1.0                beeswarm_0.3.1               
 [85] filelock_1.0.2                curl_4.3.1                   
 [87] png_0.1-7                     interactiveDisplayBase_1.30.0
 [89] statmod_1.4.36                tibble_3.1.2                 
 [91] bslib_0.2.5.1                 stringi_1.6.2                
 [93] highr_0.9                     RSpectra_0.16-0              
 [95] lattice_0.20-44               ProtGenerics_1.24.0          
 [97] Matrix_1.3-3                  vctrs_0.3.8                  
 [99] pillar_1.6.1                  lifecycle_1.0.0              
[101] BiocManager_1.30.15           Rdpack_2.1.1                 
[103] jquerylib_0.1.4               BiocNeighbors_1.10.0         
[105] data.table_1.14.0             cowplot_1.1.1                
[107] bitops_1.0-7                  irlba_2.3.3                  
[109] httpuv_1.6.1                  rtracklayer_1.52.0           
[111] R6_2.5.0                      BiocIO_1.2.0                 
[113] bookdown_0.22                 promises_1.2.0.1             
[115] KernSmooth_2.23-20            gridExtra_2.3                
[117] parallelly_1.25.0             vipor_0.4.5                  
[119] codetools_0.2-18              assertthat_0.2.1             
[121] rjson_0.2.20                  sparsepca_0.1.2              
[123] withr_2.4.2                   GenomicAlignments_1.28.0     
[125] Rsamtools_2.8.0               GenomeInfoDbData_1.2.6       
[127] hms_1.1.0                     grid_4.1.0                   
[129] beachmat_2.8.0                rmarkdown_2.8                
[131] DelayedMatrixStats_1.14.0     Rtsne_0.15                   
[133] shiny_1.6.0                   ggbeeswarm_0.6.0             
[135] restfulr_0.0.13              
```
</div>
