# Paul mouse HSC (MARS-seq)

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Introduction

This performs an analysis of the mouse haematopoietic stem cell (HSC) dataset generated with MARS-seq [@paul2015transcriptional].
Cells were extracted from multiple mice under different experimental conditions (i.e., sorting protocols) and libraries were prepared using a series of 384-well plates.

## Data loading


```r
library(scRNAseq)
sce.paul <- PaulHSCData(ensembl=TRUE)
```


```r
library(AnnotationHub)
ens.mm.v97 <- AnnotationHub()[["AH73905"]]
anno <- select(ens.mm.v97, keys=rownames(sce.paul), 
    keytype="GENEID", columns=c("SYMBOL", "SEQNAME"))
rowData(sce.paul) <- anno[match(rownames(sce.paul), anno$GENEID),]
```

After loading and annotation, we inspect the resulting `SingleCellExperiment` object:


```r
sce.paul
```

```
## class: SingleCellExperiment 
## dim: 17483 10368 
## metadata(0):
## assays(1): counts
## rownames(17483): ENSMUSG00000007777 ENSMUSG00000107002 ...
##   ENSMUSG00000039068 ENSMUSG00000064363
## rowData names(3): GENEID SYMBOL SEQNAME
## colnames(10368): W29953 W29954 ... W76335 W76336
## colData names(13): Well_ID Seq_batch_ID ... CD34_measurement
##   FcgR3_measurement
## reducedDimNames(0):
## mainExpName: NULL
## altExpNames(0):
```

## Quality control


```r
unfiltered <- sce.paul
```

For some reason, only one mitochondrial transcripts are available, so we will perform quality control using only the library size and number of detected features.
Ideally, we would simply block on the plate of origin to account for differences in processing, but unfortunately, it seems that many plates have a large proportion (if not outright majority) of cells with poor values for both metrics.
We identify such plates based on the presence of very low outlier thresholds, for some arbitrary definition of "low"; we then redefine thresholds using information from the other (presumably high-quality) plates.


```r
library(scater)
stats <- perCellQCMetrics(sce.paul) 
qc <- quickPerCellQC(stats, batch=sce.paul$Plate_ID)

# Detecting batches with unusually low threshold values.
lib.thresholds <- attr(qc$low_lib_size, "thresholds")["lower",]
nfeat.thresholds <- attr(qc$low_n_features, "thresholds")["lower",]
ignore <- union(names(lib.thresholds)[lib.thresholds < 100],
    names(nfeat.thresholds)[nfeat.thresholds < 100])

# Repeating the QC using only the "high-quality" batches.
qc2 <- quickPerCellQC(stats, batch=sce.paul$Plate_ID,
    subset=!sce.paul$Plate_ID %in% ignore)
sce.paul <- sce.paul[,!qc2$discard]
```

We examine the number of cells discarded for each reason.


```r
colSums(as.matrix(qc2))
```

```
##   low_lib_size low_n_features        discard 
##           1695           1781           1783
```

We create some diagnostic plots for each metric (Figure \@ref(fig:unref-paul-qc-dist)).


```r
colData(unfiltered) <- cbind(colData(unfiltered), stats)
unfiltered$discard <- qc2$discard
unfiltered$Plate_ID <- factor(unfiltered$Plate_ID)

gridExtra::grid.arrange(
    plotColData(unfiltered, y="sum", x="Plate_ID", colour_by="discard") +
        scale_y_log10() + ggtitle("Total count"),
    plotColData(unfiltered, y="detected", x="Plate_ID", colour_by="discard") +
        scale_y_log10() + ggtitle("Detected features"),
    ncol=1
)
```

<div class="figure">
<img src="paul-hsc_files/figure-html/unref-paul-qc-dist-1.png" alt="Distribution of each QC metric across cells in the Paul HSC dataset. Each point represents a cell and is colored according to whether that cell was discarded." width="672" />
<p class="caption">(\#fig:unref-paul-qc-dist)Distribution of each QC metric across cells in the Paul HSC dataset. Each point represents a cell and is colored according to whether that cell was discarded.</p>
</div>

## Normalization


```r
library(scran)
set.seed(101000110)
clusters <- quickCluster(sce.paul)
sce.paul <- computeSumFactors(sce.paul, clusters=clusters)
sce.paul <- logNormCounts(sce.paul)
```

We examine some key metrics for the distribution of size factors, and compare it to the library sizes as a sanity check (Figure \@ref(fig:unref-paul-norm)).


```r
summary(sizeFactors(sce.paul))
```

```
##    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
##   0.057   0.422   0.775   1.000   1.335   9.654
```


```r
plot(librarySizeFactors(sce.paul), sizeFactors(sce.paul), pch=16,
    xlab="Library size factors", ylab="Deconvolution factors", log="xy")
```

<div class="figure">
<img src="paul-hsc_files/figure-html/unref-paul-norm-1.png" alt="Relationship between the library size factors and the deconvolution size factors in the Paul HSC dataset." width="672" />
<p class="caption">(\#fig:unref-paul-norm)Relationship between the library size factors and the deconvolution size factors in the Paul HSC dataset.</p>
</div>

## Variance modelling

We fit a mean-variance trend to the endogenous genes to detect highly variable genes.
Unfortunately, the plates are confounded with an experimental treatment (`Batch_desc`) so we cannot block on the plate of origin.


```r
set.seed(00010101)
dec.paul <- modelGeneVarByPoisson(sce.paul)
top.paul <- getTopHVGs(dec.paul, prop=0.1)
```


```r
plot(dec.paul$mean, dec.paul$total, pch=16, cex=0.5, 
    xlab="Mean of log-expression", ylab="Variance of log-expression")
curve(metadata(dec.paul)$trend(x), col="blue", add=TRUE)
```

<div class="figure">
<img src="paul-hsc_files/figure-html/unref-paul-var-1.png" alt="Per-gene variance as a function of the mean for the log-expression values in the Paul HSC dataset. Each point represents a gene (black) with the mean-variance trend (blue) fitted to simulated Poisson noise." width="672" />
<p class="caption">(\#fig:unref-paul-var)Per-gene variance as a function of the mean for the log-expression values in the Paul HSC dataset. Each point represents a gene (black) with the mean-variance trend (blue) fitted to simulated Poisson noise.</p>
</div>

## Dimensionality reduction


```r
set.seed(101010011)
sce.paul <- denoisePCA(sce.paul, technical=dec.paul, subset.row=top.paul)
sce.paul <- runTSNE(sce.paul, dimred="PCA")
```

We check that the number of retained PCs is sensible.


```r
ncol(reducedDim(sce.paul, "PCA"))
```

```
## [1] 13
```

## Clustering


```r
snn.gr <- buildSNNGraph(sce.paul, use.dimred="PCA", type="jaccard")
colLabels(sce.paul) <- factor(igraph::cluster_louvain(snn.gr)$membership)
```

These is a strong relationship between the cluster and the experimental treatment (Figure \@ref(fig:unref-paul-heat)), which is to be expected.
Of course, this may also be attributable to some batch effect; the confounded nature of the experimental design makes it difficult to make any confident statements either way.


```r
tab <- table(colLabels(sce.paul), sce.paul$Batch_desc)
rownames(tab) <- paste("Cluster", rownames(tab))
pheatmap::pheatmap(log10(tab+10), color=viridis::viridis(100))
```

<div class="figure">
<img src="paul-hsc_files/figure-html/unref-paul-heat-1.png" alt="Heatmap of the distribution of cells across clusters (rows) for each experimental treatment (column)." width="672" />
<p class="caption">(\#fig:unref-paul-heat)Heatmap of the distribution of cells across clusters (rows) for each experimental treatment (column).</p>
</div>


```r
plotTSNE(sce.paul, colour_by="label")
```

<div class="figure">
<img src="paul-hsc_files/figure-html/unref-paul-tsne-1.png" alt="Obligatory $t$-SNE plot of the Paul HSC dataset, where each point represents a cell and is colored according to the assigned cluster." width="672" />
<p class="caption">(\#fig:unref-paul-tsne)Obligatory $t$-SNE plot of the Paul HSC dataset, where each point represents a cell and is colored according to the assigned cluster.</p>
</div>


```r
plotTSNE(sce.paul, colour_by="label", other_fields="Batch_desc") + 
    facet_wrap(~Batch_desc)
```

<div class="figure">
<img src="paul-hsc_files/figure-html/unref-paul-tsne2-1.png" alt="Obligatory $t$-SNE plot of the Paul HSC dataset faceted by the treatment condition, where each point represents a cell and is colored according to the assigned cluster." width="768" />
<p class="caption">(\#fig:unref-paul-tsne2)Obligatory $t$-SNE plot of the Paul HSC dataset faceted by the treatment condition, where each point represents a cell and is colored according to the assigned cluster.</p>
</div>

## Session Info {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R version 4.1.0 (2021-05-18)
Platform: x86_64-pc-linux-gnu (64-bit)
Running under: Ubuntu 20.04.2 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.13-bioc/R/lib/libRblas.so
LAPACK: /home/biocbuild/bbs-3.13-bioc/R/lib/libRlapack.so

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_US.UTF-8        LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

attached base packages:
[1] parallel  stats4    stats     graphics  grDevices utils     datasets 
[8] methods   base     

other attached packages:
 [1] scran_1.20.0                scater_1.20.0              
 [3] ggplot2_3.3.3               scuttle_1.2.0              
 [5] AnnotationHub_3.0.0         BiocFileCache_2.0.0        
 [7] dbplyr_2.1.1                ensembldb_2.16.0           
 [9] AnnotationFilter_1.16.0     GenomicFeatures_1.44.0     
[11] AnnotationDbi_1.54.0        scRNAseq_2.6.0             
[13] SingleCellExperiment_1.14.0 SummarizedExperiment_1.22.0
[15] Biobase_2.52.0              GenomicRanges_1.44.0       
[17] GenomeInfoDb_1.28.0         IRanges_2.26.0             
[19] S4Vectors_0.30.0            BiocGenerics_0.38.0        
[21] MatrixGenerics_1.4.0        matrixStats_0.58.0         
[23] BiocStyle_2.20.0            rebook_1.2.0               

loaded via a namespace (and not attached):
  [1] igraph_1.2.6                  lazyeval_0.2.2               
  [3] BiocParallel_1.26.0           digest_0.6.27                
  [5] htmltools_0.5.1.1             viridis_0.6.1                
  [7] fansi_0.4.2                   magrittr_2.0.1               
  [9] memoise_2.0.0                 ScaledMatrix_1.0.0           
 [11] cluster_2.1.2                 limma_3.48.0                 
 [13] Biostrings_2.60.0             prettyunits_1.1.1            
 [15] colorspace_2.0-1              blob_1.2.1                   
 [17] rappdirs_0.3.3                xfun_0.23                    
 [19] dplyr_1.0.6                   crayon_1.4.1                 
 [21] RCurl_1.98-1.3                jsonlite_1.7.2               
 [23] graph_1.70.0                  glue_1.4.2                   
 [25] gtable_0.3.0                  zlibbioc_1.38.0              
 [27] XVector_0.32.0                DelayedArray_0.18.0          
 [29] BiocSingular_1.8.0            scales_1.1.1                 
 [31] pheatmap_1.0.12               edgeR_3.34.0                 
 [33] DBI_1.1.1                     Rcpp_1.0.6                   
 [35] viridisLite_0.4.0             xtable_1.8-4                 
 [37] progress_1.2.2                dqrng_0.3.0                  
 [39] bit_4.0.4                     rsvd_1.0.5                   
 [41] metapod_1.0.0                 httr_1.4.2                   
 [43] RColorBrewer_1.1-2            dir.expiry_1.0.0             
 [45] ellipsis_0.3.2                pkgconfig_2.0.3              
 [47] XML_3.99-0.6                  farver_2.1.0                 
 [49] CodeDepends_0.6.5             sass_0.4.0                   
 [51] locfit_1.5-9.4                utf8_1.2.1                   
 [53] labeling_0.4.2                tidyselect_1.1.1             
 [55] rlang_0.4.11                  later_1.2.0                  
 [57] munsell_0.5.0                 BiocVersion_3.13.1           
 [59] tools_4.1.0                   cachem_1.0.5                 
 [61] generics_0.1.0                RSQLite_2.2.7                
 [63] ExperimentHub_2.0.0           evaluate_0.14                
 [65] stringr_1.4.0                 fastmap_1.1.0                
 [67] yaml_2.2.1                    knitr_1.33                   
 [69] bit64_4.0.5                   purrr_0.3.4                  
 [71] KEGGREST_1.32.0               sparseMatrixStats_1.4.0      
 [73] mime_0.10                     biomaRt_2.48.0               
 [75] compiler_4.1.0                beeswarm_0.3.1               
 [77] filelock_1.0.2                curl_4.3.1                   
 [79] png_0.1-7                     interactiveDisplayBase_1.30.0
 [81] statmod_1.4.36                tibble_3.1.2                 
 [83] bslib_0.2.5.1                 stringi_1.6.2                
 [85] highr_0.9                     lattice_0.20-44              
 [87] bluster_1.2.0                 ProtGenerics_1.24.0          
 [89] Matrix_1.3-3                  vctrs_0.3.8                  
 [91] pillar_1.6.1                  lifecycle_1.0.0              
 [93] BiocManager_1.30.15           jquerylib_0.1.4              
 [95] BiocNeighbors_1.10.0          cowplot_1.1.1                
 [97] bitops_1.0-7                  irlba_2.3.3                  
 [99] httpuv_1.6.1                  rtracklayer_1.52.0           
[101] R6_2.5.0                      BiocIO_1.2.0                 
[103] bookdown_0.22                 promises_1.2.0.1             
[105] gridExtra_2.3                 vipor_0.4.5                  
[107] codetools_0.2-18              assertthat_0.2.1             
[109] rjson_0.2.20                  withr_2.4.2                  
[111] GenomicAlignments_1.28.0      Rsamtools_2.8.0              
[113] GenomeInfoDbData_1.2.6        hms_1.1.0                    
[115] grid_4.1.0                    beachmat_2.8.0               
[117] rmarkdown_2.8                 DelayedMatrixStats_1.14.0    
[119] Rtsne_0.15                    shiny_1.6.0                  
[121] ggbeeswarm_0.6.0              restfulr_0.0.13              
```
</div>
